""" Functions to get the trainer-avatar-image from staffavatars.xml. """


from bs4 import BeautifulSoup


def get_trainer_avatar(staffavatars_xml):
    """
    Get a complex dict object to render the trainer
    avatar from staffavatars.xml
    """
    trainer_avatar_dict = {}

    trainer_avatar_soup = BeautifulSoup(staffavatars_xml, "xml")

    Trainer_tag = trainer_avatar_soup.find("Trainer")

    Layer_tags = Trainer_tag.Avatar.find_all("Layer")

    trainer_id, *_ = Trainer_tag.TrainerId.contents

    trainer_avatar_dict["trainer_id"] = trainer_id

    _tuples = [
        ("backgrounds", "avatar_background"),
        ("bodies", "avatar_body"),
        ("faces", "avatar_face"),
        ("eyes", "avatar_eyes"),
        ("mouths", "avatar_mouth"),
        ("noses", "avatar_nose"),
        ("hair", "avatar_hair"),
    ]

    for Layer_tag in Layer_tags:
        for _tuple in _tuples:
            if str(Layer_tag.Image.contents).find(_tuple[0]) != -1:
                _x = int(Layer_tag.get("x")) - 4
                _y = int(Layer_tag.get("y")) - 5
                _url = Layer_tag.Image.contents[0]
                trainer_avatar_dict[_tuple[1]] = {
                    "left": f"{_x}px",
                    "top": f"{_y}px",
                    "url": _url,
                }

    return trainer_avatar_dict



""" Functions and to get data about the series/ league of a team. """


from bs4 import BeautifulSoup


def get_my_series(search_series_xml):
    """
    Get a dict object with important infos
    for a specific series from search.xml
    """
    series_soup = BeautifulSoup(search_series_xml, "xml")

    SearchLeagueID_tag = series_soup.find("SearchLeagueID")
    ResultName_tag = series_soup.find("ResultName")
    ResultID_tag = series_soup.find("ResultID")

    nation_id, *_ = SearchLeagueID_tag.contents
    series_name, *_ = ResultName_tag.contents
    series_id, *_ = ResultID_tag.contents

    series_dict = {
        "nation_id": nation_id,
        "series_name": series_name,
        "series_id": series_id,
    }

    return series_dict


def get_teams_in_series(teams_in_series_xml):
    """
    Get a complex dict object with all important infos
    for a specific series aggregated from search.xml and
    leaguedetails.xml
    """
    tis_soup = BeautifulSoup(teams_in_series_xml, "xml")

    LeagueID_tag = tis_soup.find("LeagueID")
    LeagueLevelUnitName_tag = tis_soup.find("LeagueLevelUnitName")
    LeagueLevelUnitID_tag = tis_soup.find("LeagueLevelUnitID")

    Team_tags = tis_soup.find_all("Team")

    nation_id, *_ = LeagueID_tag.contents
    series_name, *_ = LeagueLevelUnitName_tag.contents
    series_id, *_ = LeagueLevelUnitID_tag.contents

    series_dict = {
        "nation_id": nation_id,
        "series_name": series_name,
        "series_id": series_id,
        "series_teams": [],
    }

    for Team_tag in Team_tags:
        team_id, *_ = Team_tag.TeamID.contents

        series_dict["series_teams"].append(team_id)

    return series_dict



""" Functions to get data from matchdetails.xml. """


from bs4 import BeautifulSoup


def get_matchdetails(matchdetails_xml):
    """
    Get a complex dict object with important infos
    for a specific user from matchdetails.xml
    """

    match_dict = {}

    match_soup = BeautifulSoup(matchdetails_xml, "xml")

    Match_tag = match_soup.find("Match")
    HomeTeam_tag = match_soup.find("HomeTeam")
    AwayTeam_tag = match_soup.find("AwayTeam")
    Arena_tag = match_soup.find("Arena")

    match_id, *_ = Match_tag.MatchID.contents
    match_date, *_ = Match_tag.MatchDate.contents
    match_type, *_ = Match_tag.MatchType.contents

    home_team_id, *_ = HomeTeam_tag.HomeTeamID.contents
    home_team_name, *_ = HomeTeam_tag.HomeTeamName.contents
    try:
        home_team_goals, *_ = HomeTeam_tag.HomeGoals.contents
    except Exception:
        home_team_goals = ""

    away_team_id, *_ = AwayTeam_tag.AwayTeamID.contents
    away_team_name, *_ = AwayTeam_tag.AwayTeamName.contents
    try:
        away_team_goals, *_ = AwayTeam_tag.AwayGoals.contents
    except Exception:
        away_team_goals = ""

    arena_id, *_ = Arena_tag.ArenaID.contents
    arena_name, *_ = Arena_tag.ArenaName.contents

    match_dict = {
        "match_id": match_id,
        "match_date": match_date,
        "match_type": match_type,
        "home_team_id": home_team_id,
        "home_team_name": home_team_name,
        "home_team_goals": home_team_goals,
        "away_team_id": away_team_id,
        "away_team_name": away_team_name,
        "away_team_goals": away_team_goals,
        "arena_id": arena_id,
        "arena_name": arena_name,
    }

    return match_dict



""" Functions to get data from teamdetails.xml. """


from bs4 import BeautifulSoup


def get_teamdetails(teamdetails_xml):
    """
    Get a complex dict object with important infos
    for a specific user from teamdetails.xml
    """

    team_dict = {}

    team_soup = BeautifulSoup(teamdetails_xml, "xml")

    User_tag = team_soup.find("User")
    Team_tags = team_soup.find_all("Team")

    user_id, *_ = User_tag.UserID.contents

    try:
        login_name, *_ = User_tag.Loginname.contents
    except ValueError:
        login_name = "bot"

    supporter_tier, *_ = User_tag.SupporterTier.contents
    signup_date, *_ = User_tag.SignupDate.contents
    last_login_date, *_ = User_tag.LastLoginDate.contents

    team_dict["user"] = {
        "user_id": user_id,
        "login_name": login_name,
        "supporter_tier": supporter_tier,
        "signup_date": signup_date,
        "last_login_date": last_login_date,
    }

    for Team_tag in Team_tags:
        team_id, *_ = Team_tag.TeamID.contents
        team_name, *_ = Team_tag.TeamName.contents
        team_short, *_ = Team_tag.ShortTeamName.contents
        team_primary, *_ = Team_tag.IsPrimaryClub.contents
        team_country_id, *_ = Team_tag.League.LeagueID.contents

        try:
            (
                team_league_level_unit_id,
                *_,
            ) = Team_tag.LeagueLevelUnit.LeagueLevelUnitID.contents
        except AttributeError:
            team_league_level_unit_id = ""
            team_league_level_unit_name = ""
            team_league_level_unit_level = ""
        else:
            (
                team_league_level_unit_name,
                *_,
            ) = Team_tag.LeagueLevelUnit.LeagueLevelUnitName.contents
            (
                team_league_level_unit_level,
                *_,
            ) = Team_tag.LeagueLevelUnit.LeagueLevel.contents

        team_is_bot, *_ = Team_tag.BotStatus.IsBot.contents

        try:
            team_in_cup, *_ = Team_tag.Cup.StillInCup.contents
        except AttributeError:
            team_in_cup = "True"

        team_dict[team_id] = {
            "team_name": team_name,
            "team_short": team_short,
            "team_primary": team_primary,
            "team_country_id": team_country_id,
            "team_league_level_unit_id": team_league_level_unit_id,
            "team_league_level_unit_name": team_league_level_unit_name,
            "team_league_level_unit_level": team_league_level_unit_level,
            "team_is_bot": team_is_bot,
            "team_in_cup": team_in_cup,
        }

    return team_dict



""" Function to get data from worlddetails.xml. """


from bs4 import BeautifulSoup


def get_my_worlddetails(worlddetails_xml):
    """Get a complex dict object with important infos for a specific nation from worlddetails.xml"""

    world_dict = {}

    world_soup = BeautifulSoup(worlddetails_xml, "xml")

    LeagueID_tag = world_soup.find("LeagueID")
    LeagueName_tag = world_soup.find("LeagueName")
    NumberOfLevels_tag = world_soup.find("NumberOfLevels")
    MatchRound_tag = world_soup.find("MatchRound")

    league_id, *_ = LeagueID_tag.contents
    league_name, *_ = LeagueName_tag.contents
    league_depth, *_ = NumberOfLevels_tag.contents
    season_round, *_ = MatchRound_tag.contents

    world_dict = {
        "league_id": league_id,
        "league_name": league_name,
        "league_depth": league_depth,
        "season_round": season_round,
    }

    return world_dict



"""
Functions and helper-functions to manage challenges for friendlies.

So far it is possible to get a list of challenged teams, to challenge one 
or multiple opponent teams as well as get information about fixures already
arranged.
"""


from bs4 import BeautifulSoup

from . import config


def is_challengeable(challengeable_xml):
    """
    Get a list object with challengeable teams
    from challengeable.xml
    """
    challengeable_teams = []

    challengeable_soup = BeautifulSoup(challengeable_xml, "xml")

    Opponent_tags = challengeable_soup.find_all("Opponent")

    for Opponent_tag in Opponent_tags:
        try:
            team_id, *_ = Opponent_tag.TeamId.contents
        except Exception as e:
            print(e)
            team_id = None

        try:
            _is_challengeable, *_ = Opponent_tag.IsChallengeable.contents
        except Exception as e:
            print(e)
            _is_challengeable = "False"

        if _is_challengeable == "True":
            challengeable_teams.append(team_id)

    return challengeable_teams


def do_challenge(
    my_teamid, session, challengeable_teams, match_type="1", match_place="1", is_weekend_friendly="0"
):
    """
    Takes a list of teams to challenge
    Returns status of challenges as dict
    """
    challenges = []

    for team_id in challengeable_teams:
        challenge = session.get(
            config.BASE_URL,
            params={
                "file": "challenges",
                "version": "1.6",
                "actionType": "challenge",
                "teamId": my_teamid,
                "opponentTeamId": team_id,
                "matchType": match_type,  # 0 is normal, 1 is cup rules
                "matchPlace": match_place,  # 0 is home, 1 is away, 2 is neutral
                "isWeekendFriendly": is_weekend_friendly,  # 0 is false, 1 is true
                "neutralArenaId": "",  # ArenaId for friendly on neutral ground
            },
        )

        challenge_soup = BeautifulSoup(challenge.text, "xml")

        Error_tag = challenge_soup.find_all("Error")

        if Error_tag is None:
            Opponent_tag = challenge_soup.find("Opponent")
            ArenaName_tag = challenge_soup.find("ArenaName")

            opponent_team_name, *_ = Opponent_tag.TeamName.contents
            arena_name, *_ = ArenaName_tag.contents

            challenges.append(
                {
                    "team_id": team_id,
                    "opponent_team_name": opponent_team_name,
                    "arena_name": arena_name,
                }
            )

    return challenges


def get_challenges(challenges_xml):
    """
    Get a dict object with challenged teams
    from challenges.xml
    """
    challenges = []

    challenged_teams_soup = BeautifulSoup(challenges_xml, "xml")

    Team_tag = challenged_teams_soup.find("Team")

    team_id, *_ = Team_tag.TeamID.contents
    team_name, *_ = Team_tag.TeamName.contents

    challenges = {"team_id": team_id, "team_name": team_name, "challenges": []}

    try:
        Challenge_tags = challenged_teams_soup.find_all("Challenge")

    except Exception as e:
        print(e)
        challenges = None

    else:
        for Challenge_tag in Challenge_tags:
            training_match_id, *_ = Challenge_tag.TrainingMatchID.contents

            try:
                match_id, *_ = Challenge_tag.MatchID.contents
            except Exception as e:
                print(e)
                match_id = ""

            match_time, *_ = Challenge_tag.MatchTime.contents
            friendly_type, *_ = Challenge_tag.FriendlyType.contents
            opponent_team_id, *_ = Challenge_tag.Opponent.TeamID.contents
            opponent_team_name, *_ = Challenge_tag.Opponent.TeamName.contents

            try:
                opponent_team_logo, *_ = Challenge_tag.Opponent.LogoURL.contents
            except Exception as e:
                print(e)
                opponent_team_logo = ""

            arena_id, *_ = Challenge_tag.Arena.ArenaID.contents
            arena_name, *_ = Challenge_tag.Arena.ArenaName.contents
            country_id, *_ = Challenge_tag.Country.CountryID.contents
            country_name, *_ = Challenge_tag.Country.CountryName.contents

            try:
                is_agreed, *_ = Challenge_tag.IsAgreed.contents
            except Exception as e:
                print(e)
                is_agreed = "False"

            challenges["challenges"].append(
                {
                    "training_match_id": training_match_id,
                    "match_id": match_id,
                    "match_time": match_time,
                    "friendly_type": friendly_type,
                    "opponent_team_id": opponent_team_id,
                    "opponent_team_name": opponent_team_name,
                    "opponent_team_logo": opponent_team_logo,
                    "arena_id": arena_id,
                    "arena_name": arena_name,
                    "country_id": country_id,
                    "country_name": country_name,
                    "is_agreed": is_agreed,
                }
            )

    return challenges



""" Functions for OAUTH-authentication on hattrick.org. """


from rauth import OAuth1Service  # type: ignore
from rauth import OAuth1Session

from . import config

request_client = OAuth1Service(
    consumer_key=config.OAUTH_KEY,
    consumer_secret=config.OAUTH_SECRET,
    request_token_url=config.REQUEST_TOKEN_URL,
    access_token_url=config.ACCESS_TOKEN_URL,
    authorize_url=config.AUTHORIZE_URL,
    base_url=config.BASE_URL,
)


def fetch_authorize_url(oauth_url="oob", scope=""):
    """Function for OAUTH Step 1 and 2.

    Step 1: Fetch Temporary Credential.
    Step 2: Get the auth URL.

    :param oauth_url: Default value = "oob")
    :param scope: Default value = "")
    :returns: request_token, request_token_secret
    :raises:
    """
    request_token, request_token_secret = request_client.get_request_token(
        params={
            "oauth_callback": oauth_url,
        }
    )

    authorize_url = request_client.get_authorize_url(request_token, scope=scope)

    return request_token, request_token_secret, authorize_url


def get_access_token(request_token, request_token_secret, auth_pin):
    """Function for OAUTH Step 3 and 4.

    Step 3 : Save auth_pin in var after the client was authorized.
    Step 4 : Exchange the request token for an access token.


    :param request_token:
    :param request_token_secret:
    :param auth_pin:
    :returns: access_token_key, access_token_secret
    :raises:
    """
    access_token_key, access_token_secret = request_client.get_access_token(
        request_token, request_token_secret, params={"oauth_verifier": auth_pin}
    )

    return access_token_key, access_token_secret


def open_auth_session(access_token_key, access_token_secret):
    """Function for OAUTH Step 5.

    Finally open OAUTH-session.

    :param access_token_key:
    :param access_token_secret:
    :returns: auth_session
    :raises:
    """
    my_auth_session = OAuth1Session(
        config.OAUTH_KEY,
        config.OAUTH_SECRET,
        access_token=access_token_key,
        access_token_secret=access_token_secret,
    )

    return my_auth_session



#!/usr/bin/env python3


""" SAMPLE IMPLEMENTATION FOR ht_libs. """


import json
import sys
from pathlib import Path
from time import sleep

from ht_libs import config, do_hattrick_request, get_flags, get_teamdetails

# from ht_libs import do_challenge
# from ht_libs import get_flags
# from ht_libs import get_matchdetails
# from ht_libs import get_series
# from ht_libs import get_teamdetails
# from ht_libs import get_trainer_avatar


def oauth_reg():
    # # OAuth to hattrick.org
    (
        request_token,
        request_token_secret,
        authorize_url,
    ) = do_hattrick_request.fetch_authorize_url(scope="manage_challenges")

    print(f"Open this URL and authorize Fun with Flags: {authorize_url}")

    sleep(10)

    while True:
        try:
            expression = input("Did you authorize FwF in the browser? (y/n) ")

        except (KeyboardInterrupt, EOFError):
            raise SystemExit()

        if expression.lower() in {"ja", "j", "yes", "y"}:
            try:
                pin = input("Paste the pin from the authorize-website now: ")
                break

            except (KeyboardInterrupt, EOFError):
                raise SystemExit()

        if expression.lower() in {"quit", "exit", "q", "n"}:
            raise SystemExit()

    access_token_key, access_token_secret = do_hattrick_request.get_access_token(
        request_token,
        request_token_secret,
        pin,
    )

    Path("../cache").mkdir(parents=True, exist_ok=True)

    with open("../cache/creds", "x") as f:
        f.write(f"{access_token_key} {access_token_secret}")

    return


def main():
    """
    First we try to oauth with hattrick.org and get the xml-files.
    Second you find some demo-code that shows how to use the libs.
    """
    file = Path("../cache/creds")

    if not file.is_file():
        oauth_reg()

    with open(file, "r") as f:
        line = f.readline()

        creds = []
        for cred in line.split(" "):
            creds.append(cred)

        access_token_key, access_token_secret = creds

    session = do_hattrick_request.open_auth_session(
        access_token_key, access_token_secret
    )

    status = session.get(config.TOKEN_STATUS_URL)

    if status.status_code == 200:
        try:
            teamdetails_xml = session.get(
                config.BASE_URL,
                params={
                    "file": "teamdetails",
                    "version": "3.6",
                    "includeFlags": "true",
                    "userID": "",
                },
            )

            # search_series_xml = session.get(
            #     config.base_url,
            #     params={
            #         "file": "search",
            #         "version": "1.2",
            #         "searchType": "3",
            #         "searchString": "ii.1",
            #         "searchLeagueID": "46",
            #     },
            # )

            # teams_in_series_xml = session.get(
            #     config.base_url,
            #     params={
            #         "file": "leaguedetails",
            #         "version": "1.6",
            #         "leagueLevelUnitID": "8694",
            #     },
            # )

            # challengeable_xml = session.get(
            #     config.BASE_URL,
            #     params={
            #         "file": "challenges",
            #         "version": "1.6",
            #         "actionType": "challengeable",
            #         "teamId": "2101798",
            #         "isWeekendFriendly": "1",
            #         "suggestedTeamIds": "2115616",
            #         "matchType": "1",
            #         "matchPlace": "1",
            #     },
            # )

            # challenges_xml = session.get(
            #     config.base_url,
            #     params={
            #         "file": "challenges",
            #         "version": "1.6",
            #         "actionType": "view",
            #     },
            # )

            # matchdetails_xml = session.get(
            #     config.BASE_URL,
            #     params={
            #         "file": "matchdetails",
            #         "version": "3.1",
            #         "matchEvents": "false",
            #         "matchID": "52282171",
            #         "sourceSystem": "hattrick",
            #     },
            # )

            # staffavatars_xml = session.get(
            #     config.BASE_URL,
            #     params={
            #         "file": "staffavatars",
            #         "version": "1.1",
            #         "teamId": "2101798",
            #     },
            # )

            # matches_xml = session.get(
            #     config.BASE_URL,
            #     params={
            #         "file": "matches",
            #         "version": "2.9",
            #         "teamID": "",
            #     },
            # )

            print("Download of data successful")
        except Exception as e:
            print(f"{e}: Download of ht-data failed.")
    else:
        print("Problem with oauth-login")

    # # Examples (use of hattrick-api)

    # # Example I:
    # teams_dict = get_flags.get_my_flags(teamdetails_xml.text)
    # print(teams_dict['628463']['flags_home'][0][0])

    # # Example II for a representation like on hattrick:
    _l = []
    teams_dict = get_flags.get_my_flags(teamdetails_xml.text)

    for x in range(len(teams_dict["628463"]["flags_home"])):
        w = str(teams_dict["628463"]["flags_home"][x][1])
        w = w.lower().replace("ä", "a")
        w = w.replace("ö", "o").replace("ü", "u")
        _l.append((w, (teams_dict["628463"]["flags_home"][x][0])))

    print(json.dumps(sorted(_l), indent=4))

    # # Example III:
    # all_flags = get_flags.get_all_flags()

    # print(json.dumps(all_flags, indent=4).encode('latin1')\
    #                                         .decode('unicode_escape'))

    # Example IV returns missing away flags for team x:
    # all_missing_flags = get_flags.get_missing_flags(teamdetails_xml.text)

    #print(json.dumps(all_missing_flags['628463']['missing_home'], indent=3))

    # Example V returns teamdetails for team x:
    # team_details = get_teamdetails.get_teamdetails(teamdetails_xml.text)

    # print(json.dumps(team_details, indent=4))

    # Example VI returns the series (league) with name x, nation y, teams z:
    # my_series = get_series.get_my_series(search_series_xml.text)
    # my_series_teams = get_series.get_teams_in_series(teams_in_series_xml.text)

    # print(json.dumps(my_series, indent=4))
    # print(json.dumps(my_series_teams, indent=4))

    # Example VII returns a sub-list of challegeable teams and /!\ challenge /!\:
    # my_pot_challenges = do_challenge.is_challengeable(challengeable_xml.text)
    # print(challengeable_xml.text)
    # my_challenges = do_challenge.get_challenges(challenges_xml.text)

    # print(json.dumps(my_pot_challenges, indent=4))

    # my_challenges = do_challenge.do_challenge(session, my_pot_challenges)

    # print(json.dumps(my_pot_challenges, indent=4))
    # print(my_pot_challenges)

    # Example VIII returns the details about match with id x:
    # my_match = get_matchdetails.get_matchdetails(matchdetails_xml.text)

    # print(json.dumps(my_match, indent=4))

    # Example IX returns the details necessary to compile the trainer avatar:
    # my_trainer = get_trainer_avatar.get_trainer_avatar(staffavatars_xml.text)

    # print(json.dumps(my_trainer, indent=4))

    # Example X returns the current list of future and past matches for a team:
    # my_matches = get_matches.get_matches(matches_xml.text)

    # print(json.dumps(my_matches, indent=4))


if __name__ == "__main__":
    rc = 1

    try:
        main()
        rc = 0
    except Exception as e:
        print("Error: %s" % e, file=sys.stderr)

    sys.exit(rc)



""" Functions to get data from matches. """


from bs4 import BeautifulSoup


def get_matches(matches_xml):
    """
    Get a complex dict object with future and past matches
    and corresponding details for a specific user from matches
    """

    match_dict = {}

    match_soup = BeautifulSoup(matches_xml, "xml")

    Team_tag = match_soup.find("TeamID")
    Match_tags = match_soup.find_all("Match")

    team_id, *_ = Team_tag.contents

    matches_dict = {
        "team_id": team_id,
        "matches": [],
    }

    for Match_tag in Match_tags:
        match_id, *_ = Match_tag.MatchID.contents
        home_team_id, *_ = Match_tag.HomeTeam.HomeTeamID.contents
        away_team_id, *_ = Match_tag.AwayTeam.AwayTeamID.contents
        match_date, *_ = Match_tag.MatchDate.contents
        source_system, *_ = Match_tag.SourceSystem.contents
        match_type, *_ = Match_tag.MatchType.contents
        match_status, *_ = Match_tag.Status.contents

        matches_dict["matches"].append({
            "match_id": match_id,
            "home_team_id": home_team_id,
            "away_team_id": away_team_id,
            "match_date": match_date,
            "source_system": source_system,
            "match_type": match_type,
            "match_status": match_status,
        })

    return matches_dict



"""
Functions and helper-functions to get flags of a team.

Hattrick visualizes flags in two matrices on its website. One for home- and 
one for away-flags. Further it distinguishes between flags that were already 
captured and flags still to capture. This module fetches all relevant data 
from the hattrick data-model to reproduce the same information for a given team.
"""


from bs4 import BeautifulSoup

from . import config


def compile_flags_list(flags_xml):
    """
    Helper-Function to create a list of tuples (Flags)
    """

    flags_list = []
    flags_tuples = get_all_flags()

    for flag in flags_xml:
        league_id, *_ = flag.LeagueId.contents
        country_code, *_ = flag.CountryCode.contents

        for flag_tuple in flags_tuples:
            if league_id == flag_tuple[0]:
                league_name = flag_tuple[1]
                continent = flag_tuple[3]

                li = (league_id, league_name, country_code, continent)
                flags_list.append(li)

    return flags_list


def get_all_flags():
    """
    Get a list with all available flags from config.py
    """
    all_flags = config.ALL_FLAGS
    flags_tuples = []

    for flag in all_flags:
        flag = tuple(flag)
        flags_tuples.append(flag)

    return flags_tuples


def get_my_flags(teamdetails_xml):
    """
    Get a complex dict object with all specific flags (home/away)
    for a specific user
    """

    teams_dict = {}

    team_soup = BeautifulSoup(teamdetails_xml, "xml")

    # Finding all instances of tag
    # `Team`
    Team_tags = team_soup.find_all("Team")

    for Team_tag in Team_tags:
        team_id, *_ = Team_tag.TeamID.contents

        def get_place(place):
            if place == "home":
                flags = Team_tag.Flags.HomeFlags.find_all("Flag")
            else:
                flags = Team_tag.Flags.AwayFlags.find_all("Flag")

            all_flags = compile_flags_list(flags)

            return all_flags

        for x in ["home", "away"]:
            if x == "home":
                list_flags_home = get_place(x)
            else:
                list_flags_away = get_place(x)

        teams_dict[team_id] = {
            "flags_home": list_flags_home,
            "flags_away": list_flags_away,
        }

    return teams_dict


def get_missing_flags(teamdetails_xml):
    """
    Get a complex dict object with all specific flags (home/away)
    that are missing for a specific user
    """
    missing_flags_dict = {}

    all_flags = get_all_flags()
    all_my_flags = get_my_flags(teamdetails_xml)

    teams = get_my_flags(teamdetails_xml).keys()

    for team in teams:
        missing_home = list(set(all_flags) - set(all_my_flags[team]["flags_home"]))
        missing_away = list(set(all_flags) - set(all_my_flags[team]["flags_away"]))

        missing_flags_dict[team] = {
            "missing_home": missing_home,
            "missing_away": missing_away,
        }

    return missing_flags_dict



""" Function to get data about the actual oauth token. """


from bs4 import BeautifulSoup


def request_token_status(token_status_xml):
    """
    Get a dict object about the used token
    """
    token_soup = BeautifulSoup(token_status_xml, "xml")

    UserID_tag = token_soup.find("UserID")

    user_id = UserID_tag.contents

    token_dict = {
        "user_id": user_id,
    }

    return token_dict
